@@ -1,11 +1,8 @@
-# @(#)$Ident: IO.pm 2014-01-15 16:26 pjf ;
-
 package File::DataClass::IO;
 
 use 5.010001;
 use namespace::clean -except => 'meta';
 use overload '""' => sub { shift->pathname }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.33.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use Cwd                        qw( );
@@ -285,7 +282,7 @@ sub _build__dir_pattern {
    $curdir and $updir and $pat .= '|';  # uncoverable condition left
    $updir  and $pat .= "\Q${updir}\E";  # uncoverable condition left
 
-   return qr{ \A $pat \z }mx;
+   return qr{ \A (?:$pat) \z }mx;
 }
 
 sub canonpath {
@@ -1067,10 +1064,6 @@ __END__
 
 File::DataClass::IO - Better IO syntax
 
-=head1 Version
-
-This document describes version v0.33.$Rev: 1 $ of L<File::DataClass::IO>
-
 =head1 Synopsis
 
    use File::DataClass::IO;
